parallel

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 6, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ProcessFiles

func ProcessFiles[T any](files []string, workers int, fn func(path string) (T, bool)) []T

ProcessFiles runs a function on files in parallel with a worker pool. The function fn should return (result, include) where include indicates whether to include the result in the output slice.

func ProcessFilesWithLimit

func ProcessFilesWithLimit[T any](files []string, workers, limit int, fn func(path string) (T, bool)) []T

ProcessFilesWithLimit runs a function on files in parallel with a limit. Stops processing when limit results are collected.

Types

This section is empty.

Jump to