Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ProcessFiles ¶
ProcessFiles runs a function on files in parallel with a worker pool. The function fn should return (result, include) where include indicates whether to include the result in the output slice.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.